;; Generated package description from map.el  -*- no-byte-compile: t -*-
(define-package "map" "3.0.0.20210803.222615" "Map manipulation functions" '((emacs "26")) :url "https://elpa.gnu.org/packages/map.html" :keywords '("extensions" "lisp") :authors '(("Nicolas Petton" . "nicolas@petton.fr")) :maintainer '(nil . "emacs-devel@gnu.org"))
